@@ -9,22 +9,28 @@ from .engine import Engine
 from .db_connector import (
     PostgreSQLPool,
     MySQLPool,
+    MongoPool,
     create_pool_from_env,
     create_mysql_pool_from_env,
     create_postgresql_pool_from_env,
+    create_mongo_pool_from_env,
     stream_query,
-    create_table_source
+    create_table_source,
+    create_mongo_collection_source
 )
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __all__ = [
     "Engine",
     "PostgreSQLPool",
     "MySQLPool",
+    "MongoPool",
     "create_pool_from_env",
     "create_mysql_pool_from_env",
     "create_postgresql_pool_from_env",
+    "create_mongo_pool_from_env",
     "stream_query",
-    "create_table_source"
+    "create_table_source",
+    "create_mongo_collection_source"
 ]
 
